@@ -3,25 +3,10 @@ from logging import basicConfig, getLogger
 from time import sleep
 from typing import Any, List, Union, Tuple, Sequence, Sized
 
-__version__: str = "5.0.4"
-__author__: str = 'Vlad Kochetov'
-try:
-    import numpy as np
-    from pandas import DataFrame, Series
-    from ta.volatility import AverageTrueRange
-
-    logger = getLogger(__name__)
-    getLogger('ccxt').setLevel(30)
-    getLogger('urllib3').setLevel(30)
-    logger.setLevel(10)
-    basicConfig(level=0,
-                filename='trading.log',
-                format='%(asctime)s [%(levelname)s]        %(message)s        '
-                       f'[QUICK_TRADE VERSION: {__version__}] [FUNCTION: %(funcName)s] [FILE "%(module)s", '
-                       'LINE %(lineno)d] %(name)s [%(processName)s: %(process)d] [%(threadName)s: %(thread)d] '
-                       '[FILEPATH: %(pathname)s]')
-except ModuleNotFoundError:
-    pass  # pip install error
+from _lowlev_config import __version__
+import numpy as np
+from pandas import DataFrame, Series
+from ta.volatility import AverageTrueRange
 
 SCATTER_SIZE: float = 12.0
 SCATTER_ALPHA: float = 1.0
@@ -49,23 +34,17 @@ BUY: PREDICT_TYPE = 1
 SELL: PREDICT_TYPE = 0
 EXIT: PREDICT_TYPE = 2
 
-__credits__: List[str] = ["Hemerson Tacon -- Stack overflow",
-                          "hpaulj -- Stack overflow",
-                          "furas -- Stack overflow",
-                          "Devin Jeanpierre (edit: wjandrea) -- Stack overflow",
-                          "Войтенко Николай Поликарпович (Vojtenko Nikolay Polikarpovich) -- helped me test the "
-                          "system of interaction with the binance crypto exchange with 50 dollars.",
+logger = getLogger(__name__)
+getLogger('ccxt').setLevel(30)
+getLogger('urllib3').setLevel(30)
+logger.setLevel(10)
 
-                          "https://fxgears.com/index.php?threads/how-to-acquire-free-historical-tick-and-bar-data-for"
-                          "-algo-trading-and-backtesting-in-2020-stocks-forex-and-crypto-currency.1229/#post-19305"
-                          " -- binance get historical data method",
-                          "https://www.geeksforgeeks.org/python-different-ways-to-kill-a-thread/ and "
-                          "https://teletype.in/@cozy_codespace/Hk70-Ntl4 -- heroku and threading problems",
-                          "https://stackoverflow.com/questions/57838939/handling-exceptions-with-bulk-api-requests --"
-                          "IEX token",
-                          "Igor Kroitor -- donate 0.5 ETH (~1320$)",
-                          "Igor Kroitor -- Helped to solve the problem with exception ConnectionError(10054).",
-                          "https://stackoverflow.com/questions/27333671/how-to-solve-the-10054-error"]
+basicConfig(level=0,
+            filename='trading.log',
+            format='%(asctime)s [%(levelname)s]        %(message)s        '
+                   f'[QUICK_TRADE VERSION: {__version__}] [FUNCTION: %(funcName)s] [FILE "%(module)s", '
+                   'LINE %(lineno)d] %(name)s [%(processName)s: %(process)d] [%(threadName)s: %(thread)d] '
+                   '[FILEPATH: %(pathname)s]')
 
 
 class SuperTrendIndicator(object):
